@@ -127,6 +127,26 @@
 }
 
 
+.add_pkgdown <- function(path = ".") {
+  if (!isTRUE(.dir_is_package(path))) {
+    stop(".add_pkgdown() must be run from the root of a package.", call. = FALSE)
+  }
+  url <- setdiff(desc::desc_get_urls(), .gh_url(path))
+  fn <- fs::path_join(c(path, "altdoc/pkgdown.yml"))
+  if (!fs::file_exists(fn) && length(url) > 0) {
+    url <- url[1]
+    vig <- fs::path_join(c(url, "vignettes"))
+    man <- fs::path_join(c(url, "man"))
+    content <- c(
+      "urls:",
+      paste("  reference:", man),
+      paste("  article:", vig),
+      "")
+    cli::cli_alert_info("Adding altdoc/pkgdown.yml file.")
+    writeLines(content, fn)
+  }
+}
+
 
 .add_rbuildignore <- function(x = "^docs$", path = ".") {
   if (!isTRUE(.dir_is_package(path))) {
